##
##  msmtp.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         msmtp
Summary:      Command-Line SMTP Client
URL:          https://marlam.de/msmtp/
Vendor:       Martin Lambers
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Mail
License:      GPL
Version:      1.8.26
Release:      20240512

#   list of sources
Source0:      https://marlam.de/msmtp/releases/msmtp-%{version}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  openssl, libiconv, libidn, gcrypt
PreReq:       openssl, libiconv, libidn, gcrypt

%description
    msmtp(1) is a command-line mail client to an SMTP server. Its
    features include: sendmail(8) compatible interface (command line
    options and exit codes); SASL-based authentication methods PLAIN,
    LOGIN, CRAM-MD5, DIGEST-MD5, GSSAPI, and NTLM; TLS/SSL both in
    SMTP-over-SSL mode and in STARTTLS mode; fast SMTP implementation
    using command pipelining; support for Internationalized Domain Names
    (IDN); DSN (Delivery Status Notification) support; RMQS (Remote
    Message Queue Starting) support (ETRN); optional IPv6 support and
    support for multiple accounts.

%track
    prog msmtp = {
        version   = %{version}
        url       = https://marlam.de/msmtp/download/
        regex     = msmtp-(__VER__)\.tar\.xz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="`libgcrypt-config --libs`" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --with-tls=openssl \
        --with-libidn \
        --without-libgsasl \
        --disable-nls
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

